# ChangeLog

## 1.1.0
* add function: trim
* add cli command: pysaten_trim

## 1.0.0.post4
* Add original of test code (MarbleNet)
* (No functional changes)

## 1.0.0.post3
* Modify readme
* (No functional changes)

## 1.0.0.post2
* Modify readme
* (No functional changes)

## 1.0.0.post1
* Organising the commit log
* (No functional changes)

## 1.0.0
* First Release
